@@ -249,14 +249,16 @@ class Artifacts:
 
     # Artifact 객체를 기반으로 Artifact에 등록된 모든 엔트리의 다운로드 수행
     def download(self) -> str:
-        # ./deepdriver/artifact/{artifact_id}/{tag} 폴더가 생성된다
-        local_root_path = os.path.join(".", "deepdriver", "artifact", str(self.id))
-
-
+        local_root_path = self.get_download_dir()
         # Artifact 객체가 가진 entry_list 의  ArtifactEntry.download()를 각각 호출
         for idx, entry in enumerate(self.entry_list):
             entry.download(local_root_path, self.id, self.run.team_name, self.run.exp_name, self.name, self.type, self.versioning, idx, total_file_count=len(self.entry_list))
         return local_root_path
 
+
+    def get_download_dir(self):
+        # ./deepdriver/artifact/{artifact_id}/{tag} 폴더가 생성된다
+        return os.path.join(".", "deepdriver", "artifact", str(self.id))
+
     def __str__(self) -> str:
         return "[" + ",".join(str(entry) for entry in self.entry_list) + "]"
