@@ -207,7 +207,7 @@ def upload_file(upload_type: str, local_path: str, root_path: str, path: str, ru
                 last_file_yn: str, teamName: str, expName: str, run_name: str, artifact_name: str, artifact_type: str,
                 artifact_digest: str, entry_digest: str, entry_list: List[ArtifactEntry], file_index: int) -> bool:
     logger.debug(
-        f"upload_file : {locals()}")
+        f"upload_file() : {locals()}")
 
     rsp: UploadFileResponse = get_stub().upload_file(
         load_file(upload_type, local_path, root_path, path, run_id, artifact_id, last_file_yn, teamName, expName,
@@ -239,6 +239,9 @@ def download_file(path: str, artifact_id: int, local_path: str, team_name: str,
                   file_size: int):
     # TODO 응답에 digest 값을 받아 추후 각 파일에 대한 정합성 체크시 활용한다.
 
+    logger.debug(
+        f"download_file() : {locals()}")
+
     save_file(local_path, file_index, total_file_count, file_size, get_stub().download_file(DownloadFileRequest(
         path=path,
         artifact_id=artifact_id,
